@@ -21,8 +21,7 @@ package org.blurayx.s3d.media;
 
 import javax.media.Control;
 
-public abstract interface GraphicsOffsetSequenceControl extends Control
-{
+public abstract interface GraphicsOffsetSequenceControl extends Control {
     public abstract int getSequenceId();
 
     public abstract void setSequenceId(int paramInt)
@@ -31,4 +30,4 @@ public abstract interface GraphicsOffsetSequenceControl extends Control
     public abstract void addOffsetSequenceChangeListener(GraphicsOffsetSequenceChangeListener paramGraphicsOffsetSequenceChangeListener);
 
     public abstract void removeOffsetSequenceChangeListener(GraphicsOffsetSequenceChangeListener paramGraphicsOffsetSequenceChangeListener);
-}
\ No newline at end of file
+}
