@@ -22,18 +22,16 @@ package org.dvb.media;
 import java.util.EventObject;
 
 public class SubtitleAvailableEvent extends EventObject {
-    public SubtitleAvailableEvent(Object source)
-    {
+    public SubtitleAvailableEvent(Object source) {
         super(source);
 
         this.source = source;
     }
 
-    public Object getSource()
-    {
+    public Object getSource() {
         return source;
     }
 
-    private Object source;
+    protected final Object source;
     private static final long serialVersionUID = -7714072037836958718L;
 }
