@@ -19,14 +19,13 @@
 
 package org.havi.ui;
 
-public class HChangeData
-{
-    public HChangeData(int hint, Object data)
-    {
+public class HChangeData {
+
+    public HChangeData(int hint, Object data) {
         this.hint = hint;
         this.data = data;
     }
-    
+
     public int hint;
     public Object data;
 }
