@@ -22,7 +22,15 @@ package org.videolan;
 
 class BDJThreadGroup extends ThreadGroup {
 
-    protected BDJThreadGroup(String name, BDJXletContext context) {
+    protected static BDJThreadGroup create(String name, BDJXletContext context) {
+        if (context == null) {
+            logger.error("Missing context");
+            throw new NullPointerException();
+        }
+        return new BDJThreadGroup(name, context);
+    }
+
+    private BDJThreadGroup(String name, BDJXletContext context) {
         super(name);
         this.context = context;
     }
@@ -58,7 +66,8 @@ class BDJThreadGroup extends ThreadGroup {
                (System.currentTimeMillis() < endTime)) {
             try {
                 Thread.sleep(10);
-            } catch (InterruptedException e) { }
+            } catch (InterruptedException e) {
+            }
         }
 
         boolean result = (activeCount() <= maxThreads);
@@ -81,7 +90,9 @@ class BDJThreadGroup extends ThreadGroup {
             waitForShutdown(500, 0);
         }
 
-        if (destroyed) return;
+        if (destroyed) {
+            return;
+        }
 
         try {
             destroy();
