@@ -25,19 +25,17 @@ import org.bluray.media.AudioMetadataControl;
 
 // TODO: Figure out what the hell this is for
 public class AudioMetadataControlImpl implements AudioMetadataControl {
-    public Component getControlComponent()
-    {
+    public Component getControlComponent() {
         return null;
     }
 
-    public boolean isMetaDataProcessingOn()
-    {
-        throw new Error("Not implemented"); // TODO implement
+    public boolean isMetaDataProcessingOn() {
+        org.videolan.Logger.unimplemented("AudioMetadataControlImpl", "");
+        return false;
     }
 
-    public void setMetaDataProcessingOn(boolean value)
-    {
-        throw new Error("Not implemented"); // TODO implement
+    public void setMetaDataProcessingOn(boolean value) {
+        org.videolan.Logger.unimplemented("AudioMetadataControlImpl", "");
     }
 
 }
