@@ -35,6 +35,8 @@
 #include "util/mutex.h"
 #include "util/time.h"
 
+#include "bdnav/uo_mask.h"
+
 #include "../register.h"
 #include "../keys.h"
 
@@ -81,7 +83,7 @@ struct graphics_controller_s {
     unsigned        popup_visible;
     unsigned        valid_mouse_position;
     unsigned        auto_action_triggered;
-    BOG_DATA       *bog_data;
+    BOG_DATA        bog_data[MAX_NUM_BOGS];
     BOG_DATA       *saved_bog_data;
     BD_UO_MASK      page_uo_mask;
 
@@ -357,10 +359,6 @@ static void _reset_user_timeout(GRAPHICS_CONTROLLER *gc)
 
 static int _save_page_state(GRAPHICS_CONTROLLER *gc)
 {
-    if (!gc->bog_data) {
-        GC_TRACE("_save_page_state(): no bog data !\n");
-        return -1;
-    }
     if (!gc->igs || !gc->igs->ics) {
         GC_TRACE("_save_page_state(): no IG composition\n");
         return -1;
@@ -381,7 +379,7 @@ static int _save_page_state(GRAPHICS_CONTROLLER *gc)
     /* copy enabled button state, clear draw state */
 
     X_FREE(gc->saved_bog_data);
-    gc->saved_bog_data = calloc(page->num_bogs, sizeof(*gc->saved_bog_data));
+    gc->saved_bog_data = calloc(1, sizeof(gc->bog_data));
     if (!gc->saved_bog_data) {
         GC_ERROR("_save_page_state(): out of memory\n");
         return -1;
@@ -401,13 +399,8 @@ static int _restore_page_state(GRAPHICS_CONTROLLER *gc)
     gc->out_effects = NULL;
 
     if (gc->saved_bog_data) {
-        if (gc->bog_data) {
-            GC_ERROR("_restore_page_state(): bog data already exists !\n");
-            X_FREE(gc->bog_data);
-        }
-        gc->bog_data       = gc->saved_bog_data;
-        gc->saved_bog_data = NULL;
-
+        memcpy(gc->bog_data, gc->saved_bog_data, sizeof(gc->bog_data));
+        X_FREE(gc->saved_bog_data);
         return 1;
     }
     return -1;
@@ -427,10 +420,7 @@ static void _reset_page_state(GRAPHICS_CONTROLLER *gc)
         return;
     }
 
-    size_t size = page->num_bogs * sizeof(*gc->bog_data);
-    gc->bog_data = realloc(gc->bog_data, size);
-
-    memset(gc->bog_data, 0, size);
+    memset(gc->bog_data, 0, sizeof(gc->bog_data));
 
     for (ii = 0; ii < page->num_bogs; ii++) {
         gc->bog_data[ii].enabled_button = page->bog[ii].default_valid_button_id_ref;
@@ -628,8 +618,13 @@ static void _render_composition_object(GRAPHICS_CONTROLLER *gc,
 
         if (cobj->crop_flag) {
             if (cobj->crop_x || cobj->crop_y || cobj->crop_w != object->width) {
-                ov.img = cropped_img = rle_crop_object(object->img, object->width,
-                                                       cobj->crop_x, cobj->crop_y, cobj->crop_w, cobj->crop_h);
+                cropped_img = rle_crop_object(object->img, object->width,
+                                              cobj->crop_x, cobj->crop_y, cobj->crop_w, cobj->crop_h);
+                if (!cropped_img) {
+                    BD_DEBUG(DBG_DECODE | DBG_CRIT, "Error cropping PG object\n");
+                    return;
+                }
+                ov.img = cropped_img;
             }
             ov.w  = cobj->crop_w;
             ov.h  = cobj->crop_h;
@@ -732,7 +727,7 @@ static void _gc_reset(GRAPHICS_CONTROLLER *gc)
 
     gc->popup_visible = 0;
     gc->valid_mouse_position = 0;
-    gc->page_uo_mask = bd_empty_uo_mask();
+    gc->page_uo_mask = uo_mask_get_empty();
 
     graphics_processor_free(&gc->igp);
     graphics_processor_free(&gc->pgp);
@@ -746,7 +741,7 @@ static void _gc_reset(GRAPHICS_CONTROLLER *gc)
     gc->next_dialog_idx = 0;
     gc->textst_user_style = -1;
 
-    X_FREE(gc->bog_data);
+    memset(gc->bog_data, 0, sizeof(gc->bog_data));
 }
 
 /*
@@ -971,26 +966,38 @@ static int _render_textst_region(GRAPHICS_CONTROLLER *p, int64_t pts, BD_TEXTST_
     uint16_t y;
     RLE_ENC  rle;
 
-    rle_begin(&rle);
+    if (rle_begin(&rle) < 0) {
+        return -1;
+    }
 
     for (y = 0, bmp_y = 0; y < style->region_info.region.height; y++) {
         if (y < style->text_box.ypos || y >= style->text_box.ypos + style->text_box.height) {
-            rle_add_bite(&rle, style->region_info.background_color, style->region_info.region.width);
+            if (rle_add_bite(&rle, style->region_info.background_color, style->region_info.region.width) < 0)
+                break;
         } else {
-            rle_add_bite(&rle, style->region_info.background_color, style->text_box.xpos);
-            rle_compress_chunk(&rle, bmp->mem + bmp->stride * bmp_y, bmp->width);
+            if (rle_add_bite(&rle, style->region_info.background_color, style->text_box.xpos) < 0)
+                break;
+            if (rle_compress_chunk(&rle, bmp->mem + bmp->stride * bmp_y, bmp->width) < 0)
+                break;
             bmp_y++;
-            rle_add_bite(&rle, style->region_info.background_color,
-                         style->region_info.region.width - style->text_box.width - style->text_box.xpos);
+            if (rle_add_bite(&rle, style->region_info.background_color,
+                             style->region_info.region.width - style->text_box.width - style->text_box.xpos) < 0)
+                break;
         }
 
-        rle_add_eol(&rle);
+        if (rle_add_eol(&rle) < 0)
+            break;
     }
 
-    _render_rle(p, pts, rle_get(&rle),
-                style->region_info.region.xpos, style->region_info.region.ypos,
-                style->region_info.region.width, style->region_info.region.height,
-                palette);
+    BD_PG_RLE_ELEM *img = rle_get(&rle);
+    if (img) {
+        _render_rle(p, pts, img,
+                    style->region_info.region.xpos, style->region_info.region.ypos,
+                    style->region_info.region.width, style->region_info.region.height,
+                    palette);
+    } else {
+        BD_DEBUG(DBG_DECODE | DBG_CRIT, "Error encoding Text Subtitle region\n");
+    }
 
     rle_end(&rle);
 
@@ -1020,7 +1027,7 @@ static int _render_textst(GRAPHICS_CONTROLLER *p, uint32_t stc, GC_NAV_CMDS *cmd
 
         /* next dialog too far in future ? */
         if (now < 1 || dialog[ii].start_pts >= now + 90000) {
-            GC_TRACE("_render_textst(): next event #%d in %"PRId64" seconds (pts %"PRId64")\n",
+            GC_TRACE("_render_textst(): next event #%d in %" PRId64 " seconds (pts %" PRId64 ")\n",
                      ii, (dialog[ii].start_pts - now)/90000, dialog[ii].start_pts);
             if (cmds) {
                 cmds->wakeup_time = (uint32_t)(dialog[ii].start_pts / 2);
@@ -1045,7 +1052,7 @@ static int _render_textst(GRAPHICS_CONTROLLER *p, uint32_t stc, GC_NAV_CMDS *cmd
             continue;
         }
 
-        GC_TRACE("_render_textst(): rendering dialog #%d (pts %"PRId64", diff %"PRId64"\n",
+        GC_TRACE("_render_textst(): rendering dialog #%d (pts %" PRId64 ", diff %" PRId64 "\n",
                  ii, dialog[ii].start_pts, dialog[ii].start_pts - now);
 
 
@@ -1374,7 +1381,7 @@ static int _render_page(GRAPHICS_CONTROLLER *gc,
 
     if (s->ics->interactive_composition.ui_model == IG_UI_MODEL_POPUP && !gc->popup_visible) {
 
-        gc->page_uo_mask = bd_empty_uo_mask();
+        gc->page_uo_mask = uo_mask_get_empty();
 
         if (gc->ig_open) {
             GC_TRACE("_render_page(): popup menu not visible\n");
@@ -1929,7 +1936,7 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
         cmds->nav_cmds     = NULL;
         cmds->sound_id_ref = -1;
         cmds->status       = GC_STATUS_NONE;
-        cmds->page_uo_mask = bd_empty_uo_mask();
+        cmds->page_uo_mask = uo_mask_get_empty();
     }
 
     if (!gc) {
@@ -1996,8 +2003,9 @@ int gc_run(GRAPHICS_CONTROLLER *gc, gc_ctrl_e ctrl, uint32_t param, GC_NAV_CMDS
                 result = _user_input(gc, param, cmds);
                 break;
             }
+            /* BD_VK_POPUP => GC_CTRL_POPUP */
             param = !gc->popup_visible;
-            /* fall thru (BD_VK_POPUP) */
+            /* fall thru */
 
         case GC_CTRL_POPUP:
             if (gc->igs->ics->interactive_composition.ui_model != IG_UI_MODEL_POPUP) {
